/*
 * Copyright (c) 2016 LabKey Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.labkey.labwork;

import org.labkey.api.action.FormViewAction;
import org.labkey.api.action.Marshal;
import org.labkey.api.action.Marshaller;
import org.labkey.api.action.SpringActionController;
import org.labkey.api.security.RequiresPermission;
import org.labkey.api.security.permissions.ReadPermission;
import org.labkey.api.util.URLHelper;
import org.labkey.api.view.ActionURL;
import org.labkey.api.view.JspView;
import org.labkey.api.view.NavTree;
import org.labkey.api.workflow.WorkflowProcess;
import org.labkey.labwork.workflow.WorkflowHandler;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.servlet.ModelAndView;

@Marshal(Marshaller.Jackson)
public class LabWorkController extends SpringActionController
{
    private static final DefaultActionResolver _actionResolver = new DefaultActionResolver(LabWorkController.class);
    public static final String NAME = "labwork";

    public LabWorkController()
    {
        setActionResolver(_actionResolver);
    }

    @RequiresPermission(ReadPermission.class)
    public class BeginAction extends FormViewAction<WorkRequestBean>
    {

        @Override
        public NavTree appendNavTrail(NavTree root)
        {
            return null;
        }

        @Override
        public void validateCommand(WorkRequestBean bean, Errors errors)
        {
            if (bean.getAssayA() == null && bean.getAssayB() == null)
                errors.reject(ERROR_MSG, "You must select at least one assay to run.");
        }

        @Override
        public ModelAndView getView(WorkRequestBean workRequestBean, boolean reshow, BindException errors) throws Exception
        {
            return new JspView("/org/labkey/labwork/view/workRequest.jsp", null, errors);
        }

        @Override
        public boolean handlePost(WorkRequestBean form, BindException errors) throws Exception
        {
            WorkflowProcess process = WorkflowHandler.startWorkflow(form, getContainer(), getUser());
            form.setProcessInstanceId(process.getProcessInstanceId());
            return true;
        }

        @Override
        public URLHelper getSuccessURL(WorkRequestBean form)
        {
            // N.B. A UrlProvider for Workflow would get rid of the use of this deprecated constructor for ActionURL
            ActionURL url = new ActionURL("workflow", "processInstance", getContainer());
            url.addParameter("processInstanceId", form.getProcessInstanceId());
            return url;
        }
    }


    public static class WorkRequestBean
    {
        private String _assayA;
        private String  _assayB;
        private String _processInstanceId;

        public String getProcessInstanceId()
        {
            return _processInstanceId;
        }

        public void setProcessInstanceId(String processInstanceId)
        {
            _processInstanceId = processInstanceId;
        }

        public String getAssayA()
        {
            return _assayA;
        }

        public void setAssayA(String assayA)
        {
            _assayA = assayA;
        }

        public String getAssayB()
        {
            return _assayB;
        }

        public void setAssayB(String assayB)
        {
            _assayB = assayB;
        }
    }
}