/*
 * Copyright (c) 2016 LabKey Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.labkey.labwork.workflow;

import org.jetbrains.annotations.NotNull;
import org.labkey.api.data.Container;
import org.labkey.api.security.User;
import org.labkey.api.security.permissions.InsertPermission;
import org.labkey.api.security.permissions.Permission;
import org.labkey.api.workflow.PermissionsHandler;
import org.labkey.api.workflow.WorkflowProcess;
import org.labkey.api.workflow.WorkflowTask;

import java.util.Collections;
import java.util.Set;

/**
 * Permissions handler for workflow processes and tasks.  Override the base class implementations
 * to customize who can start processes, start and view tasks, delegate or assign tasks.
 */
public class PermissionsHandlerImpl extends PermissionsHandler
{
    public PermissionsHandlerImpl(User user, Container container)
    {
        super(user, container);
    }

    /**
     * Currently we allow anyone to view any process.
     * @param process the process in question
     * @return indication of whether the user used to create the permissions handler can view the process
     */
    public boolean canView(@NotNull WorkflowProcess process)
    {
        return true;
    }


    /**
     * Currently we allow anyone to view any task.
     * @param task the task in question
     * @return indication of whether the user used to create the permissions handler can view the given task
     */
    public boolean canView(@NotNull WorkflowTask task)
    {
        return true;
    }

    /**
     * Provides a set of permission classes that a user must have in order to be assigned a given task.
     * A user must have one of these permissions in order to be in the candidate
     * @param task the task that is to be assigned
     * @return set of permissions.
     */
    @Override
    public Set<Class<? extends Permission>> getCandidateUserPermissions(@NotNull WorkflowTask task)
    {
        return Collections.singleton(InsertPermission.class);
    }
}
