/*
 * Copyright (c) 2016 LabKey Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.labkey.labwork.workflow;

import org.labkey.api.data.Container;
import org.labkey.api.security.User;
import org.labkey.api.util.emailTemplate.EmailTemplate;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * Template for email to be sent when work has been delayed on running or reviewing an assay.
 */
public class WorkDelayedEmailTemplate extends EmailTemplate
{
    private static final String NAME = "Lab Work Assay Request Delayed";
    private static final String DEFAULT_SUBJECT = "Assay Work Request Delayed";
    private static final String DEFAULT_BODY = "The assay ^workType^ work requested in folder ^folder^ on ^requestDate^ by ^user^ is overdue.";
    protected List<ReplacementParam> _replacements = new ArrayList<>();

    protected User _user;
    protected Date _requestDate;
    private String _workType;

    public WorkDelayedEmailTemplate()
    {
        super(NAME);
        setSubject(DEFAULT_SUBJECT);
        setBody(DEFAULT_BODY);
        setDescription("Sent to responsible scientists to notify them when an assay request is overdue.");
        setPriority(10);
        setEditableScopes(Scope.SiteOrFolder);

        _replacements.add(new ReplacementParam<String>("folder", String.class, "Name of the folder in which the work request is made")
        {
            public String getValue(Container c)
            {
                return c.getName();
            }
        });
        _replacements.add(new ReplacementParam<String>("user", String.class, "The user that is requesting the work.")
        {
            public String getValue(Container c)
            {
                return _user == null ? "unknown" : _user.getFriendlyName();
            }
        });
        _replacements.add(new ReplacementParam<Date>("requestDate", Date.class, "The date that the request was made.")
        {
            public Date getValue(Container c)
            {
                return _requestDate;
            }
        });
        _replacements.add(new ReplacementParam<String>("workType", String.class, "The type of work to be done.")
        {
            public String getValue(Container c)
            {
                return _workType == null ? "" : _workType;
            }
        });
    }


    public void init(User user, Date date, String workType)
    {
        _user = user;
        _requestDate = date;
        _workType = workType;
    }

    @Override
    public List<ReplacementParam> getValidReplacements()
    {
        return _replacements;
    }
}
